@@ -74,18 +74,26 @@ OC.L10N.register(
     "Error while changing permissions" : "Fallu mientres camudaben los permisos",
     "Shared with you and the group {group} by {owner}" : "Compartíu contigo y col grupu {group} por {owner}",
     "Shared with you by {owner}" : "Compartíu contigo por {owner}",
+    "Share with users or groups …" : "Compartir con usuarios o grupos",
+    "Share with users, groups or remote users …" : "Compartir con usuarios, grupos o usuarios remotos",
     "Share" : "Compartir",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Compartir con xente d'otros ownClouds usando la sintaxis usuariu@exemplu.com/owncloud",
     "Share link" : "Compartir enllaz",
     "The public link will expire no later than {days} days after it is created" : "L'enllaz públicu va caducar enantes de {days} díes dende la so creación",
+    "Link" : "Enllaz",
     "Password protect" : "Protexer con contraseña",
     "Password" : "Contraseña",
     "Choose a password for the public link" : "Escueyi una contraseña pal enllaz públicu",
+    "Allow editing" : "Permitir edición",
     "Email link to person" : "Enllaz de corréu-e a la persona",
     "Send" : "Unviar",
     "Set expiration date" : "Afitar la data de caducidá",
     "Expiration" : "Caducidá",
     "Expiration date" : "Data de caducidá",
+    "An error occured. Please try again" : "Hebo un fallu. Por favor, inténtalo dempués. ",
+    "Adding user..." : "Amestando usuariu...",
     "group" : "grupu",
+    "remote" : "remotu",
     "Resharing is not allowed" : "Recompartir nun ta permitíu",
     "Shared in {item} with {user}" : "Compartíu en {item} con {user}",
     "Unshare" : "Dexar de compartir",
@@ -94,6 +102,7 @@ OC.L10N.register(
     "can edit" : "pue editar",
     "access control" : "control d'accesu",
     "create" : "crear",
+    "change" : "camudar",
     "delete" : "desaniciar",
     "Password protected" : "Contraseña protexida",
     "Error unsetting expiration date" : "Fallu desafitando la data de caducidá",
