@@ -4,7 +4,6 @@ OC.L10N.register(
     "Documents" : "Asiakirjat",
     "Can't create document" : "Asiakirjan luominen epäonnistui",
     "You don't have permission to rename this document" : "Oikeutesi eivät riitä nimeämään tätä asiakirjaa uudelleen",
-    "File does not exist" : "Tiedostoa ei ole olemassa",
     "Directory saved successfully." : "Kansio tallennettiin onnistuneesti.",
     "An error occurred while changing directory." : "Virhe kansiota vaihtaessa.",
     "Saved" : "Tallennettu",
@@ -120,7 +119,6 @@ OC.L10N.register(
     "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice on asennettu erillisille palvelimelle, joka tarjoaa muotosuodatuspalvelimen ominaisuudet",
     "Disabled" : "Ei käytössä",
     "No MS Word support" : "Ei MS Word -tukea",
-    "scheme://domain.tld[:port]" : "scheme://domain.tld[:port]",
     "Server URL" : "Palvelimen osoite",
     "Apply and test" : "Toteuta ja testaa",
     "New document" : "Uusi asiakirja",
@@ -129,7 +127,6 @@ OC.L10N.register(
     "Save new documents to" : "Uusien asiakirjojen tallennussijainti",
     "Wrong password. Please retry." : "Väärä salasana. Yritä uudelleen.",
     "Guest %s" : "Vieras %s",
-    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Linkki on vanhentunut tai se ei ole ollutkaan toimiva. Ota yhteyttä henkilöön jolta sait linkin saadaksesi lisätietoja.",
     "Advanced feature-set" : "Tarkemmat toiminto-asetukset",
     "(Unstable)" : "(Epävakaa)"
 },
